@@ -24,15 +24,24 @@ def plot(df, x, y, kind, **kwargs):
     elif kind == 'scatter':
         if 'style' not in kwargs:
             kwargs['style'] = 'o'
-        return finplot.plot(_x, _y, **kwargs)
+        if type(x) is str and type(y) is str and _x is not None and _y is not None:
+            return finplot.plot(_x, _y, **kwargs)
+        else:
+            return finplot.plot(df, **kwargs)
     elif kind == 'bar':
-        return finplot.bar(_x, _y, **kwargs)
+        if type(x) is str and type(y) is str and _x is not None and _y is not None:
+            return finplot.bar(_x, _y, **kwargs)
+        else:
+            return finplot.bar(df, **kwargs)
     elif kind in ('barh', 'horiz_time_volume'):
         return finplot.horiz_time_volume(df, **kwargs)
     elif kind in ('heatmap'):
         return finplot.heatmap(df, **kwargs)
     elif kind in ('labels'):
-        return finplot.labels(df, **kwargs)
+        if type(x) is str and type(y) is str and _x is not None and _y is not None:
+            return finplot.labels(_x, _y, **kwargs)
+        else:
+            return finplot.labels(df, **kwargs)
     elif kind in ('hist', 'histogram'):
         return finplot.hist(df, **kwargs)
     else:
